use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( examples lib script t xt ) );
__DATA__
Any
Berjon
Chris
Dagfinn
Doran
Etheridge
Graham
Horsfall
Hunter
Ilmari
JSON
Justin
Karen
Knop
Kogman
Mannsåker
Marc
Matthew
Mims
Prather
Rinaldo
Robin
Thompson
Todd
Tomas
Yuval
bobtfish
chris
cthom
ether
haarg
ilmari
irc
justin
lib
marc
nothingmuch
robin
toddr
wolfsage
יובל
קוג
